@@ -13,13 +13,10 @@ from contextlib import contextmanager
 
 import pytz
 from celery import current_app as current_celery_app
-from elasticsearch import VERSION as ES_VERSION
-from elasticsearch.helpers import bulk
-from elasticsearch.helpers import expand_action as default_expand_action
-from elasticsearch_dsl import Index
 from flask import current_app
 from invenio_records.api import Record
 from invenio_search import current_search_client
+from invenio_search.engine import dsl, search
 from invenio_search.utils import build_alias_name
 from kombu import Producer as KombuProducer
 from kombu.compat import Consumer
@@ -27,7 +24,9 @@ from sqlalchemy.orm.exc import NoResultFound
 
 from .proxies import current_record_to_index
 from .signals import before_record_index
-from .utils import _es7_expand_action
+
+# the tests expect this to be present
+bulk = search.helpers.bulk
 
 
 class Producer(KombuProducer):
@@ -38,12 +37,12 @@ class Producer(KombuProducer):
 
     def publish(self, data, **kwargs):
         """Validate operation type."""
-        assert data.get('op') in {'index', 'create', 'delete', 'update'}
+        assert data.get("op") in {"index", "create", "delete", "update"}
         return super(Producer, self).publish(data, **kwargs)
 
 
 class RecordIndexer(object):
-    r"""Provide an interface for indexing records in Elasticsearch.
+    r"""Provide an interface for indexing records in the search engine.
 
     Bulk indexing works by queuing requests for indexing records and processing
     these requests in bulk.
@@ -59,23 +58,31 @@ class RecordIndexer(object):
     record_dumper = None
     """Dumper instance to use with this record indexer."""
 
-    def __init__(self, search_client=None, exchange=None, queue=None,
-                 routing_key=None, version_type=None, record_to_index=None,
-                 record_cls=None, record_dumper=None):
+    def __init__(
+        self,
+        search_client=None,
+        exchange=None,
+        queue=None,
+        routing_key=None,
+        version_type=None,
+        record_to_index=None,
+        record_cls=None,
+        record_dumper=None,
+    ):
         """Initialize indexer.
 
-        :param search_client: Elasticsearch client.
+        :param search_client: search engine client.
             (Default: ``current_search_client``)
         :param exchange: A :class:`kombu.Exchange` instance for message queue.
         :param queue: A :class:`kombu.Queue` instance for message queue.
         :param routing_key: Routing key for message queue.
-        :param version_type: Elasticsearch version type.
+        :param version_type: search engine version type.
             (Default: ``external_gte``)
         :param record_to_index: Function to extract the index and doc_type
             from the record.
         :param record_cls: Record class used for retriving and dumping records.
             If the ``Record.enable_jsonref`` flag is False, new-style record
-            dumping will be used for creating the Elasticsearch source
+            dumping will be used for creating the search engine source
             document.
         :param record_dumper: Dumper instance to use for dumping the record.
             Only has an effect for new-style record dumping.
@@ -85,7 +92,7 @@ class RecordIndexer(object):
         self._queue = queue
         self._record_to_index = record_to_index or current_record_to_index
         self._routing_key = routing_key
-        self._version_type = version_type or 'external_gte'
+        self._version_type = version_type or "external_gte"
 
         if record_cls:
             self.record_cls = record_cls
@@ -106,7 +113,7 @@ class RecordIndexer(object):
 
         :returns: The Message Queue queue.
         """
-        return self._queue or current_app.config['INDEXER_MQ_QUEUE']
+        return self._queue or current_app.config["INDEXER_MQ_QUEUE"]
 
     @property
     def mq_exchange(self):
@@ -114,7 +121,7 @@ class RecordIndexer(object):
 
         :returns: The Message Queue exchange.
         """
-        return self._exchange or current_app.config['INDEXER_MQ_EXCHANGE']
+        return self._exchange or current_app.config["INDEXER_MQ_EXCHANGE"]
 
     @property
     def mq_routing_key(self):
@@ -122,8 +129,7 @@ class RecordIndexer(object):
 
         :returns: The Message Queue routing key.
         """
-        return (self._routing_key or
-                current_app.config['INDEXER_MQ_ROUTING_KEY'])
+        return self._routing_key or current_app.config["INDEXER_MQ_ROUTING_KEY"]
 
     #
     # High-level API
@@ -141,8 +147,7 @@ class RecordIndexer(object):
         """
         index, doc_type = self.record_to_index(record)
         arguments = arguments or {}
-        body = self._prepare_record(
-            record, index, doc_type, arguments, **kwargs)
+        body = self._prepare_record(record, index, doc_type, arguments, **kwargs)
         index, doc_type = self._prepare_index(index, doc_type)
 
         return self.client.index(
@@ -171,7 +176,7 @@ class RecordIndexer(object):
         """
         if not index:
             index_name = self.record_cls.index._name
-        elif isinstance(index, Index):
+        elif isinstance(index, dsl.Index):
             index_name = index._name
         else:
             index_name = index
@@ -188,7 +193,7 @@ class RecordIndexer(object):
         """
         if not index:
             index_name = self.record_cls.index._name
-        elif isinstance(index, Index):
+        elif isinstance(index, dsl.Index):
             index_name = index._name
         else:
             index_name = index
@@ -201,26 +206,22 @@ class RecordIndexer(object):
         """Delete a record.
 
         :param record: Record instance.
-        :param kwargs: Passed to
-            :meth:`elasticsearch:elasticsearch.Elasticsearch.delete`.
+        :param kwargs: Passed to `search.delete`.
         """
         index, doc_type = self.record_to_index(record)
         index, doc_type = self._prepare_index(index, doc_type)
 
         # Pop version arguments for backward compatibility if they were
         # explicit set to None in the function call.
-        if 'version' in kwargs and kwargs['version'] is None:
-            kwargs.pop('version', None)
-            kwargs.pop('version_type', None)
+        if "version" in kwargs and kwargs["version"] is None:
+            kwargs.pop("version", None)
+            kwargs.pop("version_type", None)
         else:
-            kwargs.setdefault('version', record.revision_id)
-            kwargs.setdefault('version_type', self._version_type)
+            kwargs.setdefault("version", record.revision_id)
+            kwargs.setdefault("version_type", self._version_type)
 
         return self.client.delete(
-            id=str(record.id),
-            index=index,
-            doc_type=doc_type,
-            **kwargs
+            id=str(record.id), index=index, doc_type=doc_type, **kwargs
         )
 
     def delete_by_id(self, record_uuid, **kwargs):
@@ -236,20 +237,19 @@ class RecordIndexer(object):
 
         :param record_id_iterator: Iterator yielding record UUIDs.
         """
-        self._bulk_op(record_id_iterator, 'index')
+        self._bulk_op(record_id_iterator, "index")
 
     def bulk_delete(self, record_id_iterator):
         """Bulk delete records from index.
 
         :param record_id_iterator: Iterator yielding record UUIDs.
         """
-        self._bulk_op(record_id_iterator, 'delete')
+        self._bulk_op(record_id_iterator, "delete")
 
-    def process_bulk_queue(self, es_bulk_kwargs=None):
+    def process_bulk_queue(self, search_bulk_kwargs=None):
         """Process bulk indexing queue.
 
-        :param dict es_bulk_kwargs: Passed to
-            :func:`elasticsearch:elasticsearch.helpers.bulk`.
+        :param dict search_bulk_kwargs: Passed to `search.helpers.bulk`.
         """
         with current_celery_app.pool.acquire(block=True) as conn:
             consumer = Consumer(
@@ -259,19 +259,17 @@ class RecordIndexer(object):
                 routing_key=self.mq_routing_key,
             )
 
-            req_timeout = current_app.config['INDEXER_BULK_REQUEST_TIMEOUT']
+            req_timeout = current_app.config["INDEXER_BULK_REQUEST_TIMEOUT"]
+
+            search_bulk_kwargs = search_bulk_kwargs or {}
 
-            es_bulk_kwargs = es_bulk_kwargs or {}
             count = bulk(
                 self.client,
                 self._actionsiter(consumer.iterqueue()),
                 stats_only=True,
                 request_timeout=req_timeout,
-                expand_action_callback=(
-                    _es7_expand_action if ES_VERSION[0] >= 7
-                    else default_expand_action
-                ),
-                **es_bulk_kwargs
+                expand_action_callback=search.helpers.expand_action,
+                **search_bulk_kwargs
             )
 
             consumer.close()
@@ -293,13 +291,13 @@ class RecordIndexer(object):
     # Low-level implementation
     #
     def _bulk_op(self, record_id_iterator, op_type, index=None, doc_type=None):
-        """Index record in Elasticsearch asynchronously.
+        """Index record in the search engine asynchronously.
 
         :param record_id_iterator: dIterator that yields record UUIDs.
         :param op_type: Indexing operation (one of ``index``, ``create``,
             ``delete`` or ``update``).
-        :param index: The Elasticsearch index. (Default: ``None``)
-        :param doc_type: The Elasticsearch doc_type. (Default: ``None``)
+        :param index: The search engine index. (Default: ``None``)
+        :param doc_type: The search engine doc_type. (Default: ``None``)
         """
         with self.create_producer() as producer:
             for rec in record_id_iterator:
@@ -319,7 +317,7 @@ class RecordIndexer(object):
         for message in message_iterator:
             payload = message.decode()
             try:
-                if payload['op'] == 'delete':
+                if payload["op"] == "delete":
                     yield self._delete_action(payload)
                 else:
                     yield self._index_action(payload)
@@ -329,36 +327,36 @@ class RecordIndexer(object):
             except Exception:
                 message.reject()
                 current_app.logger.error(
-                    "Failed to index record {0}".format(payload.get('id')),
-                    exc_info=True)
+                    "Failed to index record {0}".format(payload.get("id")),
+                    exc_info=True,
+                )
 
     def _delete_action(self, payload):
         """Bulk delete action.
 
         :param payload: Decoded message body.
-        :returns: Dictionary defining an Elasticsearch bulk 'delete' action.
+        :returns: Dictionary defining the search engine bulk 'delete' action.
         """
         kwargs = {}
-        index, doc_type = payload.get('index'), payload.get('doc_type')
+        index, doc_type = payload.get("index"), payload.get("doc_type")
         if not (index and doc_type):
-            record = self.record_cls.get_record(
-                payload['id'], with_deleted=True)
+            record = self.record_cls.get_record(payload["id"], with_deleted=True)
             index, doc_type = self.record_to_index(record)
-            kwargs['_version'] = record.revision_id
-            kwargs['_version_type'] = self._version_type
+            kwargs["_version"] = record.revision_id
+            kwargs["_version_type"] = self._version_type
         else:
             # Allow version to be sent in the payload (but only use if we
             # haven't loaded the record.
-            if 'version' in payload:
-                kwargs['_version'] = payload['version']
-                kwargs['_version_type'] = self._version_type
+            if "version" in payload:
+                kwargs["_version"] = payload["version"]
+                kwargs["_version_type"] = self._version_type
         index, doc_type = self._prepare_index(index, doc_type)
 
         return {
-            '_op_type': 'delete',
-            '_index': index,
-            '_type': doc_type,
-            '_id': payload['id'],
+            "_op_type": "delete",
+            "_index": index,
+            "_type": doc_type,
+            "_id": payload["id"],
             **kwargs,
         }
 
@@ -366,9 +364,9 @@ class RecordIndexer(object):
         """Bulk index action.
 
         :param payload: Decoded message body.
-        :returns: Dictionary defining an Elasticsearch bulk 'index' action.
+        :returns: Dictionary defining the search engine bulk 'index' action.
         """
-        record = self.record_cls.get_record(payload['id'])
+        record = self.record_cls.get_record(payload["id"])
         index, doc_type = self.record_to_index(record)
 
         arguments = {}
@@ -376,13 +374,13 @@ class RecordIndexer(object):
         index, doc_type = self._prepare_index(index, doc_type)
 
         action = {
-            '_op_type': 'index',
-            '_index': index,
-            '_type': doc_type,
-            '_id': str(record.id),
-            '_version': record.revision_id,
-            '_version_type': self._version_type,
-            '_source': body
+            "_op_type": "index",
+            "_index": index,
+            "_type": doc_type,
+            "_id": str(record.id),
+            "_version": record.revision_id,
+            "_version_type": self._version_type,
+            "_source": body,
         }
         action.update(arguments)
 
@@ -392,11 +390,10 @@ class RecordIndexer(object):
         """Prepare the index/doc_type before an operation."""
         return build_alias_name(index), doc_type
 
-    def _prepare_record(self, record, index, doc_type, arguments=None,
-                        **kwargs):
+    def _prepare_record(self, record, index, doc_type, arguments=None, **kwargs):
         """Prepare record data for indexing.
 
-        Invenio-Records is evolving and preparing an Elasticsearch source
+        Invenio-Records is evolving and preparing the search engine source
         document is now a responsibility of the Record class. For backward
         compatibility, we use the ``Record.enable_jsonref`` flag to control
         if we use the new record dumpers feature from Invenio-Records. Set the
@@ -404,15 +401,15 @@ class RecordIndexer(object):
         style record dumping.
 
         :param record: The record to prepare.
-        :param index: The Elasticsearch index.
-        :param doc_type: The Elasticsearch document type.
-        :param arguments: The arguments to send to Elasticsearch upon indexing.
+        :param index: The search engine index.
+        :param doc_type: The search engine document type.
+        :param arguments: The arguments to send to the search engine upon indexing.
         :param **kwargs: Extra parameters.
-        :returns: The Elasticsearch source document.
+        :returns: The search engine source document.
         """
         # New-style record dumping - we use the Record.enable_jsonref flag on
         # the Record to control if we use the new simplified dumping.
-        if not getattr(record, 'enable_jsonref', True):
+        if not getattr(record, "enable_jsonref", True):
             # If dumper is None, dumps() will use the default configured dumper
             # on the Record class.
             return record.dumps(dumper=self.record_dumper)
@@ -422,17 +419,19 @@ class RecordIndexer(object):
         # is backward compatible for new-style records. Also, we're adding
         # extra information into the record like _created and _updated
         # afterwards, which the Record.dumps() have no control over.
-        if current_app.config['INDEXER_REPLACE_REFS']:
+        if current_app.config["INDEXER_REPLACE_REFS"]:
             data = copy.deepcopy(record.replace_refs())
         else:
             data = record.dumps()
 
-        data['_created'] = pytz.utc.localize(record.created).isoformat() \
-            if record.created else None
-        data['_updated'] = pytz.utc.localize(record.updated).isoformat() \
-            if record.updated else None
+        data["_created"] = (
+            pytz.utc.localize(record.created).isoformat() if record.created else None
+        )
+        data["_updated"] = (
+            pytz.utc.localize(record.updated).isoformat() if record.updated else None
+        )
 
-        # Allow modification of data prior to sending to Elasticsearch.
+        # Allow modification of data prior to sending to the search engine.
         before_record_index.send(
             current_app._get_current_object(),
             json=data,
@@ -447,7 +446,7 @@ class RecordIndexer(object):
 
 
 class BulkRecordIndexer(RecordIndexer):
-    r"""Provide an interface for indexing records in Elasticsearch.
+    r"""Provide an interface for indexing records in the search engine.
 
     Uses bulk indexing by default.
     """
